@@ -218,7 +218,7 @@ class verify_signature_TestCase(
     default_args = dict(
             host="foo",
             check_only=False,
-            unsigned_upload=False,
+            allow_unsigned_uploads=False,
             binary_upload=False,
             debug=None,
             )
@@ -303,7 +303,7 @@ class verify_signature_ChecksTestCase(verify_signature_TestCase):
             ('source unsigned', {
                 'extra_args': {
                     'binary_upload': False,
-                    'unsigned_upload': True,
+                    'allow_unsigned_uploads': True,
                     },
                 'expected_checks': [],
                 }),
@@ -324,7 +324,7 @@ class verify_signature_ChecksTestCase(verify_signature_TestCase):
             ('binary unsigned', {
                 'extra_args': {
                     'binary_upload': True,
-                    'unsigned_upload': True,
+                    'allow_unsigned_uploads': True,
                     },
                 'expected_checks': [],
                 }),
@@ -443,10 +443,11 @@ class create_upload_file_TestCase(
         self.package_file_name = (
                 os.path.splitext(changes_file_name)[0] + ".source")
         self.test_args = dict(
-                package=self.package_file_name,
+                changes_file_name=self.package_file_name,
                 host=self.test_host,
                 fqdn=self.test_fqdn,
-                path=os.path.dirname(self.changes_file_double.path),
+                changes_file_directory=os.path.dirname(
+                    self.changes_file_double.path),
                 files_to_upload=self.fake_upload_file_paths,
                 debug=False,
                 )
@@ -1247,11 +1248,11 @@ class check_upload_logfile_TestCase(
     def set_test_args(self):
         """ Set the arguments for the test call to the function. """
         self.test_args = dict(
-                changes_file=self.changes_file_double.path,
+                changes_file_path=self.changes_file_double.path,
                 host=self.test_host,
                 fqdn=self.runtime_config_parser.get(self.test_host, 'fqdn'),
                 check_only=False,
-                call_lintian=False,
+                run_lintian=False,
                 force_upload=False,
                 debug=False,
                 )
@@ -1367,7 +1368,7 @@ class check_upload_logfile_ErrorTestCase(check_upload_logfile_TestCase):
         sys.exit.assert_called_with(self.expected_exit_status)
 
 
-# Copyright © 2015–2018 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2021 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
